"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useGlobalScrollSpyOf = void 0;
var react_1 = require("react");
var GlobalScrollSpyContext_1 = require("./GlobalScrollSpyContext");
/**
 * @returns [ isActive, actions ] - Two return values are returned as an array
 * @returns isActive - Whether the DOM element specified by key is active
 * @returns actions - Actions are used to control registered DOM elements specified by key
 */
var useGlobalScrollSpyOf = function (key) {
    var _a = (0, react_1.useContext)(GlobalScrollSpyContext_1.GlobalScrollSpyContext), activeElement = _a.activeElement, actions = _a.actions;
    var isActive = (activeElement === null || activeElement === void 0 ? void 0 : activeElement.key) === key;
    var registerElement = (0, react_1.useCallback)(function (element) {
        actions.registerElement({ key: key, element: element });
    }, [actions, key]);
    var unregisterElement = (0, react_1.useCallback)(function () {
        actions.unregisterElement({ key: key });
    }, [actions, key]);
    return [isActive, { registerElement: registerElement, unregisterElement: unregisterElement }];
};
exports.useGlobalScrollSpyOf = useGlobalScrollSpyOf;
//# sourceMappingURL=useGlobalScrollSpyOf.js.map